<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Top Travel Pro
 * @since Top Travel Pro 1.0.0
 */

if ( ! function_exists( 'top_travel_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Top Travel Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function top_travel_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'top_travel_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'top_travel_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Top Travel Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function top_travel_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'top_travel_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'top_travel_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Top Travel Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function top_travel_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'top_travel_pro_theme_options[pagination_enable]' )->value();
	}
endif;

if ( ! function_exists( 'top_travel_pro_is_static_homepage_enable' ) ) :
	/**
	 * Check if static homepage is enabled.
	 *
	 * @since Top Travel Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function top_travel_pro_is_static_homepage_enable( $control ) {
		return ( 'page' == $control->manager->get_setting( 'show_on_front' )->value() );
	}
endif;

/**
 * Front Page Active Callbacks
 */

/**
 * Check if topbar section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_topbar_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'top_travel_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout, array('default-design', 'second-design', 'third-design', 'fourth-design', 'fifth-design', 'sixth-design', 'seventh-design', 'eighth-design', 'ninth-design', 'tenth-design'));
}

/**
 * Check if topbar section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_topbar_section_enable( $control ) {
	return ( $control->manager->get_setting( 'top_travel_pro_theme_options[top_section_enable]' )->value() );
}

/**
 * Check if slider section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_slider_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'top_travel_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout, array('default-design', 'second-design', 'third-design', 'fourth-design', 'sixth-design', 'seventh-design', 'eighth-design', 'ninth-design', 'tenth-design'));
}

/**
 * Check if slider section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'top_travel_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if slider section content type is category.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[slider_content_type]' )->value();
	return top_travel_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if slider section content type is page.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[slider_content_type]' )->value();
	return top_travel_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is post.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[slider_content_type]' )->value();
	return top_travel_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}

function top_travel_pro_is_slider_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[slider_content_type]' )->value();
	return top_travel_pro_is_slider_section_enable( $control ) && ( 'trip' == $content_type );
}

function top_travel_pro_is_slider_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[slider_content_type]' )->value();
	return top_travel_pro_is_slider_section_enable( $control ) && ( 'trip-types' == $content_type );
}

function top_travel_pro_is_slider_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[slider_content_type]' )->value();
	return top_travel_pro_is_slider_section_enable( $control ) && ( 'activity' == $content_type );
}

function top_travel_pro_is_slider_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[slider_content_type]' )->value();
	return top_travel_pro_is_slider_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if popular_destination section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_popular_destination_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'top_travel_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout, array('default-design', 'third-design', 'fourth-design', 'ninth-design', 'tenth-design'));
}

/**
 * Check if popular destination section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_popular_destination_section_enable( $control ) {
	return ( $control->manager->get_setting( 'top_travel_pro_theme_options[popular_destination_section_enable]' )->value() );
}

/**
 * Check if popular destination section content type is page.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_popular_destination_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[popular_destination_content_type]' )->value();
	return top_travel_pro_is_popular_destination_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if popular destination section content type is post.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_popular_destination_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[popular_destination_content_type]' )->value();
	return top_travel_pro_is_popular_destination_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if popular destination section content type is trip.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_popular_destination_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[popular_destination_content_type]' )->value();
	return top_travel_pro_is_popular_destination_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if popular destination section content type is category.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_popular_destination_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[popular_destination_content_type]' )->value();
	return top_travel_pro_is_popular_destination_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if popular destination section content type is trip types.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_popular_destination_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[popular_destination_content_type]' )->value();
	return top_travel_pro_is_popular_destination_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if popular destination section content type is destination.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_popular_destination_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[popular_destination_content_type]' )->value();
	return top_travel_pro_is_popular_destination_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if popular destination section content type is activity.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_popular_destination_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[popular_destination_content_type]' )->value();
	return top_travel_pro_is_popular_destination_section_enable( $control ) && ( 'activity' == $content_type );
}

/**
 * Check if about section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_about_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'top_travel_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout, array('default-design', 'second-design', 'third-design', 'fourth-design', 'seventh-design', 'eighth-design', 'ninth-design', 'tenth-design'));
}

/**
 * Check if about section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'top_travel_pro_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if about section content type is post.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[about_content_type]' )->value();
	return top_travel_pro_is_about_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if about section content type is page.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[about_content_type]' )->value();
	return top_travel_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if about section content type is custom.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_about_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[about_content_type]' )->value();
	return top_travel_pro_is_about_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if about section wp travel is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_about_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[about_content_type]' )->value();
	return top_travel_pro_is_about_section_enable( $control ) && class_exists( 'WP_Travel' );
}



/**
 * Check if package section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_package_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'top_travel_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout, array('default-design'));
}

/**
 * Check if package section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_package_section_enable( $control ) {
	return ( $control->manager->get_setting( 'top_travel_pro_theme_options[package_section_enable]' )->value() );
}

/**
 * Check if package section content type is category.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_package_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[package_content_type]' )->value();
	return top_travel_pro_is_package_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if package section content type is trip types.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_package_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[package_content_type]' )->value();
	return top_travel_pro_is_package_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if package section content type is destination.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_package_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[package_content_type]' )->value();
	return top_travel_pro_is_package_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if package section content type is activity.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_package_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[package_content_type]' )->value();
	return top_travel_pro_is_package_section_enable( $control ) && ( 'activity' == $content_type );
}


/**
 * Check if service section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_service_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'top_travel_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout, array('default-design', 'second-design', 'seventh-design', 'eighth-design', 'ninth-design', 'tenth-design'));
}

/**
 * Check if service section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'top_travel_pro_theme_options[service_section_enable]' )->value() );
}


function top_travel_pro_is_service_section_icon_enable( $control ) {
	$icon = $control->manager->get_setting( 'top_travel_pro_theme_options[service_section_icon_enable]' )->value();
	return top_travel_pro_is_service_section_enable( $control ) && ( true == $icon );
}
/**
 * Check if service section content type is post.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[service_content_type]' )->value();
	return top_travel_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if service section seperator.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_service_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[service_content_type]' )->value();
	return top_travel_pro_is_service_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if service section content type is page.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[service_content_type]' )->value();
	return top_travel_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if service section content type is category.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[service_content_type]' )->value();
	return top_travel_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}

function top_travel_pro_is_service_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[service_content_type]' )->value();
	return top_travel_pro_is_service_section_enable( $control ) && ( 'trip' == $content_type );
}

function top_travel_pro_is_service_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[service_content_type]' )->value();
	return top_travel_pro_is_service_section_enable( $control ) && ( 'trip-types' == $content_type );
}

function top_travel_pro_is_service_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[service_content_type]' )->value();
	return top_travel_pro_is_service_section_enable( $control ) && ( 'activity' == $content_type );
}

function top_travel_pro_is_service_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[service_content_type]' )->value();
	return top_travel_pro_is_service_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if testimonial section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_testimonial_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'top_travel_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout, array('default-design', 'second-design', 'fourth-design', 'seventh-design'));
}

/**
 * Check if testimonial section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_testimonial_section_enable( $control ) {
	return ( $control->manager->get_setting( 'top_travel_pro_theme_options[testimonial_section_enable]' )->value() );
}

/**
 * Check if testimonial section content type is post.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_testimonial_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[testimonial_content_type]' )->value();
	return top_travel_pro_is_testimonial_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if testimonial section content type is page.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_testimonial_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[testimonial_content_type]' )->value();
	return top_travel_pro_is_testimonial_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if testimonial section content type is category.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_testimonial_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[testimonial_content_type]' )->value();
	return top_travel_pro_is_testimonial_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if testimonial section content type is custom.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_testimonial_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[testimonial_content_type]' )->value();
	return top_travel_pro_is_testimonial_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if testimonial section content type is author.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_testimonial_section_content_author_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[testimonial_content_type]' )->value();
	return top_travel_pro_is_testimonial_section_enable( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if subscription section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_subscription_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'top_travel_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout, array('default-design', 'second-design', 'third-design', 'fourth-design', 'sixth-design', 'seventh-design', 'eighth-design', 'ninth-design', 'tenth-design'));
}

/**
 * Check if subscription section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_subscription_section_enable( $control ) {
	return ( $control->manager->get_setting( 'top_travel_pro_theme_options[subscription_section_enable]' )->value() );
}

/**
 * Check if counter section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_counter_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'top_travel_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout, array('default-design', 'second-design', 'seventh-design', 'eighth-design', 'ninth-design', 'tenth-design'));
}

/**
 * Check if counter section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_counter_section_enable( $control ) {
	return ( $control->manager->get_setting( 'top_travel_pro_theme_options[counter_section_enable]' )->value() );
}

/**
 * Check if team section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_team_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'top_travel_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout, array('default-design', 'second-design', 'seventh-design', 'eighth-design', 'ninth-design'));
}

/**
 * Check if team section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_team_section_enable( $control ) {
	return ( $control->manager->get_setting( 'top_travel_pro_theme_options[team_section_enable]' )->value() );
}

/**
 * Check if team section content type is category.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_team_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[team_content_type]' )->value();
	return top_travel_pro_is_team_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if team section content type is page.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_team_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[team_content_type]' )->value();
	return top_travel_pro_is_team_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if team section content type is post.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_team_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[team_content_type]' )->value();
	return top_travel_pro_is_team_section_enable( $control ) && ( 'post' == $content_type );
}

/*trending section*/

/**
 * Check if trending section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_trending_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'top_travel_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout, array('default-design', 'third-design', 'fifth-design', 'eighth-design', 'ninth-design', 'tenth-design' ));
}

/**
 * Check if trending section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_trending_section_enable( $control ) {
	return ( $control->manager->get_setting( 'top_travel_pro_theme_options[trending_section_enable]' )->value() );
}

/**
 * Check if trending section content type is category.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_trending_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[trending_content_type]' )->value();
	return top_travel_pro_is_trending_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if trending section content type is page.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_trending_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[trending_content_type]' )->value();
	return top_travel_pro_is_trending_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if trending section content type is post.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_trending_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[trending_content_type]' )->value();
	return top_travel_pro_is_trending_section_enable( $control ) && ( 'post' == $content_type );
}

/*end trending section*/

/*recent section*/

/**
 * Check if recent section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_recent_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'top_travel_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout, array('default-design', 'third-design', 'fourth-design', 'fifth-design', 'tenth-design' ));
}

/**
 * Check if recent section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_recent_section_enable( $control ) {
	return ( $control->manager->get_setting( 'top_travel_pro_theme_options[recent_section_enable]' )->value() );
}

/**
 * Check if recent section content type is category.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_recent_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[recent_content_type]' )->value();
	return top_travel_pro_is_recent_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if recent section content type is page.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_recent_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[recent_content_type]' )->value();
	return top_travel_pro_is_recent_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if recent section content type is post.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_recent_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[recent_content_type]' )->value();
	return top_travel_pro_is_recent_section_enable( $control ) && ( 'post' == $content_type );
}

/*end recent section*/

/*popular_posts section*/

/**
 * Check if popular_posts section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_popular_posts_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'top_travel_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout, array('fifth-design' ));
}

/**
 * Check if popular_posts section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_popular_posts_section_enable( $control ) {
	return ( $control->manager->get_setting( 'top_travel_pro_theme_options[popular_posts_section_enable]' )->value() );
}

/**
 * Check if popular_posts section content type is category.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_popular_posts_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[popular_posts_content_type]' )->value();
	return top_travel_pro_is_popular_posts_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if popular_posts section content type is page.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_popular_posts_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[popular_posts_content_type]' )->value();
	return top_travel_pro_is_popular_posts_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if popular_posts section content type is post.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_popular_posts_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[popular_posts_content_type]' )->value();
	return top_travel_pro_is_popular_posts_section_enable( $control ) && ( 'post' == $content_type );
}

/*end popular_posts section*/

/*featured section*/

/**
 * Check if featured section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_featured_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'top_travel_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout, array('fifth-design' ));
}

/**
 * Check if featured section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_featured_section_enable( $control ) {
	return ( $control->manager->get_setting( 'top_travel_pro_theme_options[featured_section_enable]' )->value() );
}

/**
 * Check if featured section content type is category.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_featured_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[featured_content_type]' )->value();
	return top_travel_pro_is_featured_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if featured section content type is page.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_featured_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[featured_content_type]' )->value();
	return top_travel_pro_is_featured_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured section content type is post.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_featured_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[featured_content_type]' )->value();
	return top_travel_pro_is_featured_section_enable( $control ) && ( 'post' == $content_type );
}

/*end featured section*/

/*most_viewed section*/

/**
 * Check if most_viewed section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_most_viewed_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'top_travel_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout, array('fifth-design' ));
}

/**
 * Check if most_viewed section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_most_viewed_section_enable( $control ) {
	return ( $control->manager->get_setting( 'top_travel_pro_theme_options[most_viewed_section_enable]' )->value() );
}

/**
 * Check if most_viewed section content type is category.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_most_viewed_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[most_viewed_content_type]' )->value();
	return top_travel_pro_is_most_viewed_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if most_viewed section content type is page.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_most_viewed_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[most_viewed_content_type]' )->value();
	return top_travel_pro_is_most_viewed_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if most_viewed section content type is post.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_most_viewed_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[most_viewed_content_type]' )->value();
	return top_travel_pro_is_most_viewed_section_enable( $control ) && ( 'post' == $content_type );
}

/*end most_viewed section*/

/*single_column section*/

/**
 * Check if single_column section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_single_column_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'top_travel_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout, array('fifth-design' ));
}

/**
 * Check if single_column section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_single_column_section_enable( $control ) {
	return ( $control->manager->get_setting( 'top_travel_pro_theme_options[single_column_section_enable]' )->value() );
}

/**
 * Check if single_column section content type is category.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_single_column_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[single_column_content_type]' )->value();
	return top_travel_pro_is_single_column_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if single_column section content type is page.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_single_column_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[single_column_content_type]' )->value();
	return top_travel_pro_is_single_column_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if single_column section content type is post.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_single_column_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[single_column_content_type]' )->value();
	return top_travel_pro_is_single_column_section_enable( $control ) && ( 'post' == $content_type );
}

/*end single_column section*/

/*latest_posts section*/

/**
 * Check if latest_posts section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_latest_posts_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'top_travel_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout, array('fifth-design' ));
}

/**
 * Check if latest_posts section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_latest_posts_section_enable( $control ) {
	return ( $control->manager->get_setting( 'top_travel_pro_theme_options[latest_posts_section_enable]' )->value() );
}

/**
 * Check if latest_posts section content type is category.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_latest_posts_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[latest_posts_content_type]' )->value();
	return top_travel_pro_is_latest_posts_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if latest_posts section content type is page.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_latest_posts_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[latest_posts_content_type]' )->value();
	return top_travel_pro_is_latest_posts_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if latest_posts section content type is post.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_latest_posts_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[latest_posts_content_type]' )->value();
	return top_travel_pro_is_latest_posts_section_enable( $control ) && ( 'post' == $content_type );
}

/*end latest_posts section*/

/*latest products*/

/**
 * Check if latest_products section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_latest_products_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'top_travel_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout, array('default-design', 'sixth-design' ));
}

/**
 * Check if latest release section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_latest_products_section_enable( $control ) {
	return ( $control->manager->get_setting( 'top_travel_pro_theme_options[latest_products_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

/**
 * Check if latest release section content type is product.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_latest_products_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[latest_products_content_type]' )->value();
	return top_travel_pro_is_latest_products_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if latest release section content type is product category.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_latest_products_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[latest_products_content_type]' )->value();
	return top_travel_pro_is_latest_products_section_enable( $control ) && ( 'product-category' == $content_type );
}

/*end latest products*/

/*popular products*/

/**
 * Check if popular_products section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_popular_products_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'top_travel_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout, array('default-design', 'sixth-design' ));
}

/**
 * Check if popular_products section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_popular_products_section_enable( $control ) {
	return ( $control->manager->get_setting( 'top_travel_pro_theme_options[popular_products_section_enable]' )->value() );
}

function top_travel_pro_is_popular_products_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[popular_products_content_type]' )->value();
	return top_travel_pro_is_popular_products_section_enable( $control ) && ( 'product' == $content_type );
}

function top_travel_pro_is_popular_products_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[popular_products_content_type]' )->value();
	return top_travel_pro_is_popular_products_section_enable( $control ) && ( 'product-category' == $content_type );
}

/*end popular products*/

/**
 * Check if collection section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_collection_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'top_travel_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout, array('default-design', 'sixth-design' ));
}

/**
 * Check if product section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_collection_section_enable( $control ) {
	return ( $control->manager->get_setting( 'top_travel_pro_theme_options[collection_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

/*recent products*/

/**
 * Check if recent_products section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_recent_products_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'top_travel_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout, array('default-design', 'sixth-design' ));
}

/**
 * Check if recent_products section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_recent_products_section_enable( $control ) {
	return ( $control->manager->get_setting( 'top_travel_pro_theme_options[recent_products_section_enable]' )->value() );
}

function top_travel_pro_is_recent_products_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[recent_products_content_type]' )->value();
	return top_travel_pro_is_recent_products_section_enable( $control ) && ( 'product' == $content_type );
}

function top_travel_pro_is_recent_products_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[recent_products_content_type]' )->value();
	return top_travel_pro_is_recent_products_section_enable( $control ) && ( 'product-category' == $content_type );
}

/*end recent products*/

/**
 * Check if featured_products section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_featured_products_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'top_travel_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout, array('default-design', 'sixth-design' ));
}

//featured section
function top_travel_pro_is_featured_products_section_enable( $control ) {
	return ( $control->manager->get_setting( 'top_travel_pro_theme_options[featured_products_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

/*trending section*/

/**
 * Check if trending_product section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_trending_product_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'top_travel_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout, array('default-design', 'sixth-design' ));
}

function top_travel_pro_is_trending_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'top_travel_pro_theme_options[trending_product_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

/**
 * Check if trending_product section content type is post.
 *
 * @since musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */

function top_travel_pro_is_trending_product_section_content_category_enable_1( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[trending_content_type_1]' )->value();
	return top_travel_pro_is_trending_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

function top_travel_pro_is_trending_product_section_content_category_enable_2( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[trending_content_type_2]' )->value();
	return top_travel_pro_is_trending_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

function top_travel_pro_is_trending_product_section_content_category_enable_3( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[trending_content_type_3]' )->value();
	return top_travel_pro_is_trending_product_section_enable( $control ) && ( 'product_cat' == $content_type );
}

function top_travel_pro_is_trending_product_section_content_product_enable_1( $control ) {
		$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[trending_content_type_1]' )->value();
	return top_travel_pro_is_trending_product_section_enable( $control ) && ( 'product' == $content_type );
}

function top_travel_pro_is_trending_product_section_content_product_enable_2( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[trending_content_type_2]' )->value();
	return top_travel_pro_is_trending_product_section_enable( $control ) && ( 'product' == $content_type );
}

function top_travel_pro_is_trending_product_section_content_product_enable_3( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[trending_content_type_3]' )->value();
	return top_travel_pro_is_trending_product_section_enable( $control ) && ( 'product' == $content_type );
}

/*end trending section*/

/*gallery section*/

/**
 * Check if gallery section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_gallery_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'top_travel_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout, array('default-design', 'ninth-design', 'tenth-design' ));
}

/**
 * Check if gallery section is enabled.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_gallery_section_enable( $control ) {
	return ( $control->manager->get_setting( 'top_travel_pro_theme_options[gallery_section_enable]' )->value() );
}

/**
 * Check if gallery section content type is category.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_gallery_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[gallery_content_type]' )->value();
	return top_travel_pro_is_gallery_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if gallery section content type is page.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_gallery_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[gallery_content_type]' )->value();
	return top_travel_pro_is_gallery_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if gallery section content type is post.
 *
 * @since Top Travel Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function top_travel_pro_is_gallery_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'top_travel_pro_theme_options[gallery_content_type]' )->value();
	return top_travel_pro_is_gallery_section_enable( $control ) && ( 'post' == $content_type );
}

/*end gallery section*/
