<?php
/**
 * Latest Products Section options
 *
 * @package Theme Palace
 * @subpackage Top Travel Pro
 * @since Top Travel Pro 1.0.0
 */
	if( !class_exists( 'WooCommerce' ) ){
		return;
	}

// Add Latest Products section
$wp_customize->add_section( 'top_travel_pro_latest_products_section', array(
	'title'             => esc_html__( 'Latest Products','top-travel-pro' ),
	'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'top-travel-pro' ),
	'panel'             => 'top_travel_pro_front_page_panel',
	'active_callback'   => 'top_travel_pro_is_latest_products_design_enable',
) );

// Latest Products content enable control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[latest_products_section_enable]', array(
	'default'			=> 	$options['latest_products_section_enable'],
	'sanitize_callback' => 'top_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Top_Travel_Pro_Switch_Control( $wp_customize, 'top_travel_pro_theme_options[latest_products_section_enable]', array(
	'label'             => esc_html__( 'Latest Products Section Enable', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_latest_products_section',
	'on_off_label' 		=> top_travel_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[latest_products_section_enable]', array(
		'selector'            => '#latest-products .wrapper',
		'settings'            => 'top_travel_pro_theme_options[latest_products_section_enable]',
    ) );
}

// content type control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[latest_products_count]', array(
	'default'          	=> $options['latest_products_count'],
	'sanitize_callback' => 'top_travel_pro_sanitize_number_range',
	'validate_callback' => 'top_travel_pro_validate_latest_products_count',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[latest_products_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'top-travel-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_latest_products_section',
	'active_callback'   => 'top_travel_pro_is_latest_products_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Latest Products content type control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[latest_products_content_type]', array(
	'default'          	=> $options['latest_products_content_type'],
	'sanitize_callback' => 'top_travel_pro_sanitize_select',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[latest_products_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_latest_products_section',
	'type'				=> 'select',
	'active_callback' 	=> 'top_travel_pro_is_latest_products_section_enable',
	'choices'			=> array(
		'product'   		 => esc_html__( 'Product', 'top-travel-pro' ),
		'product-category'   => esc_html__( 'Product Category', 'top-travel-pro' ),
		),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'top_travel_pro_theme_options[latest_products_content_product_category]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'top_travel_pro_theme_options[latest_products_content_product_category]', array(
	'label'             => esc_html__( 'Select Product Category', 'top-travel-pro' ),
	'description'      	=> esc_html__( 'Note: Latest three posts will be shown from selected category', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_latest_products_section',
	'taxonomy'			=> 'product_cat',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'top_travel_pro_is_latest_products_section_content_product_category_enable'
) ) );

for ( $i = 1; $i <= $options['latest_products_count']; $i++ ) :

	// latest_products posts drop down chooser control and setting
	$wp_customize->add_setting( 'top_travel_pro_theme_options[latest_products_content_product_' . $i . ']', array(
		'sanitize_callback' => 'top_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Chooser( $wp_customize, 'top_travel_pro_theme_options[latest_products_content_product_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Product %d', 'top-travel-pro' ), $i ),
		'section'           => 'top_travel_pro_latest_products_section',
		'choices'			=> top_travel_pro_product_choices(),
		'active_callback'	=> 'top_travel_pro_is_latest_products_section_content_product_enable',
	) ) );

endfor;

/*color options*/

// Section sub title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[latest_products_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[latest_products_title_color]', array(
	'label'             => esc_html__( 'Section Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_latest_products_section',
	'active_callback' 	=> 'top_travel_pro_is_latest_products_section_enable',
	) ) );

// Section title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[latest_products_section_title_box_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[latest_products_section_title_box_color]', array(
	'label'             => esc_html__( 'Section Title Box Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_latest_products_section',
	'active_callback' 	=> 'top_travel_pro_is_latest_products_section_enable',
	) ) );
