<?php
/**
 * Popular Destination Section options
 *
 * @package Theme Palace
 * @subpackage Top Travel Pro
 * @since Top Travel Pro 1.0.0
 */

// Add Popular Destination section
$wp_customize->add_section( 'top_travel_pro_popular_destination_section', array(
	'title'             => esc_html__( 'Popular Destination','top-travel-pro' ),
	'description'       => esc_html__( 'Popular Destination Section options.', 'top-travel-pro' ),
	'panel'             => 'top_travel_pro_front_page_panel',	
	'active_callback'   => 'top_travel_pro_is_popular_destination_design_enable',
) );

// Popular Destination content enable control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[popular_destination_section_enable]', array(
	'default'			=> 	$options['popular_destination_section_enable'],
	'sanitize_callback' => 'top_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Top_Travel_Pro_Switch_Control( $wp_customize, 'top_travel_pro_theme_options[popular_destination_section_enable]', array(
	'label'             => esc_html__( 'Popular Destination Section Enable', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_popular_destination_section',
	'on_off_label' 		=> top_travel_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[popular_destination_section_enable]', array(
		'selector'            => '#popular-destinations .wrapper',
		'settings'            => 'top_travel_pro_theme_options[popular_destination_section_enable]',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[popular_destination_count]', array(
	'default'          	=> $options['popular_destination_count'],
	'sanitize_callback' => 'top_travel_pro_sanitize_number_range',
	'validate_callback' => 'top_travel_pro_validate_popular_destination_count',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[popular_destination_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'top-travel-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_popular_destination_section',
	'active_callback'   => 'top_travel_pro_is_popular_destination_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Popular Destination content type control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[popular_destination_content_type]', array(
	'default'          	=> $options['popular_destination_content_type'],
	'sanitize_callback' => 'top_travel_pro_sanitize_select',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[popular_destination_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_popular_destination_section',
	'type'				=> 'select',
	'active_callback' 	=> 'top_travel_pro_is_popular_destination_section_enable',
	'choices'			=> top_travel_pro_popular_destination_content_type(),
) );

for ( $i=1; $i <= $options['popular_destination_count']; $i++ ) { 
	// popular_destination pages drop down chooser control and setting
	$wp_customize->add_setting( 'top_travel_pro_theme_options[popular_destination_content_page_' . $i . ']', array(
		'sanitize_callback' => 'top_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Chooser( $wp_customize, 'top_travel_pro_theme_options[popular_destination_content_page_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Page %d', 'top-travel-pro' ), $i ),
		'section'           => 'top_travel_pro_popular_destination_section',
		'choices'			=> top_travel_pro_page_choices(),
		'active_callback'	=> 'top_travel_pro_is_popular_destination_section_content_page_enable',
	) ) );

	// popular_destination posts drop down chooser control and setting
	$wp_customize->add_setting( 'top_travel_pro_theme_options[popular_destination_content_post_' . $i . ']', array(
		'sanitize_callback' => 'top_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Chooser( $wp_customize, 'top_travel_pro_theme_options[popular_destination_content_post_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select posts %d', 'top-travel-pro' ), $i ),
		'section'           => 'top_travel_pro_popular_destination_section',
		'choices'			=> top_travel_pro_post_choices(),
		'active_callback'	=> 'top_travel_pro_is_popular_destination_section_content_post_enable',
	) ) );

	// popular_destination trips drop down chooser control and setting
	$wp_customize->add_setting( 'top_travel_pro_theme_options[popular_destination_content_trip_' . $i . ']', array(
		'sanitize_callback' => 'top_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Chooser( $wp_customize, 'top_travel_pro_theme_options[popular_destination_content_trip_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Trip %d', 'top-travel-pro' ), $i ),
		'section'           => 'top_travel_pro_popular_destination_section',
		'choices'			=> top_travel_pro_trip_choices(),
		'active_callback'	=> 'top_travel_pro_is_popular_destination_section_content_trip_enable',
	) ) );
}

// Add dropdown category setting and control.
$wp_customize->add_setting(  'top_travel_pro_theme_options[popular_destination_content_category]', array(
	'sanitize_callback' => 'top_travel_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'top_travel_pro_theme_options[popular_destination_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'top-travel-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_popular_destination_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'top_travel_pro_is_popular_destination_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'top_travel_pro_theme_options[popular_destination_content_trip_types]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'top_travel_pro_theme_options[popular_destination_content_trip_types]', array(
	'label'             => esc_html__( 'Select Trip Types', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_popular_destination_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'top_travel_pro_is_popular_destination_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'top_travel_pro_theme_options[popular_destination_content_activity]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'top_travel_pro_theme_options[popular_destination_content_activity]', array(
	'label'             => esc_html__( 'Select Activities', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_popular_destination_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'top_travel_pro_is_popular_destination_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'top_travel_pro_theme_options[popular_destination_content_destination]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'top_travel_pro_theme_options[popular_destination_content_destination]', array(
	'label'             => esc_html__( 'Select Destinations', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_popular_destination_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'top_travel_pro_is_popular_destination_section_content_destination_enable'
) ) );

if ( $options['home_layout'] !== 'fourth-design' ):

// destination btn title setting and control
$wp_customize->add_setting( 'top_travel_pro_theme_options[popular_destination_btn_title]', array(
	'default'			=> $options['popular_destination_btn_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[popular_destination_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'top-travel-pro' ),
	'section'        	=> 'top_travel_pro_popular_destination_section',
	'active_callback' 	=> 'top_travel_pro_is_popular_destination_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[popular_destination_btn_title]', array(
		'selector'            => '#popular-destinations .more-link a',
		'settings'            => 'top_travel_pro_theme_options[popular_destination_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'top_travel_pro_popular_destination_btn_title_partial',
    ) );
}
endif;

/*color options*/

if( $options['home_layout'] !== 'fourth-design' ):

// Popular Destination title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[popular_destination_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[popular_destination_title_color]', array(
	'label'             => esc_html__( 'Popular Destination Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_popular_destination_section',
	'active_callback' 	=> 'top_travel_pro_is_popular_destination_section_enable',
	) ) );

// Popular Destination title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[popular_destination_hover_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[popular_destination_hover_title_color]', array(
	'label'             => esc_html__( 'Popular Destination Hover Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_popular_destination_section',
	'active_callback' 	=> 'top_travel_pro_is_popular_destination_section_enable',
	) ) );

// Popular Destination description color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[popular_destination_description_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[popular_destination_description_color]', array(
	'label'             => esc_html__( 'Popular Destination Description Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_popular_destination_section',
	'active_callback' 	=> 'top_travel_pro_is_popular_destination_section_enable',
	) ) );

// Button title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[popular_destination_btn_text_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[popular_destination_btn_text_color]', array(
	'label'             => esc_html__( 'Button Text Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_popular_destination_section',
	'active_callback' 	=> 'top_travel_pro_is_popular_destination_section_enable',
	) ) );

// Header title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[popular_destination_button_text_hover_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[popular_destination_button_text_hover_color]', array(
	'label'             => esc_html__( 'Button Text Hover Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_popular_destination_section',
	'active_callback' 	=> 'top_travel_pro_is_popular_destination_section_enable',
	) ) );

endif;
