<?php
/**
 * Popular Posts Section options
 *
 * @package Theme Palace
 * @subpackage Travel Ultimate Pro
 * @since Travel Ultimate Pro 1.0.0
 */

// Add Popular Posts section
$wp_customize->add_section( 'top_travel_pro_popular_posts_section', array(
    'title'             => esc_html__( 'Popular Posts','top-travel-pro' ),
    'description'       => esc_html__( 'Popular Posts Section options.', 'top-travel-pro' ),
    'panel'             => 'top_travel_pro_front_page_panel',    
    'active_callback'   => 'top_travel_pro_is_popular_posts_design_enable',
) );

// Popular Posts content enable control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[popular_posts_section_enable]', array(
    'default'           =>  $options['popular_posts_section_enable'],
    'sanitize_callback' => 'top_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Top_Travel_Pro_Switch_Control( $wp_customize, 'top_travel_pro_theme_options[popular_posts_section_enable]', array(
    'label'             => esc_html__( 'Popular Posts Section Enable', 'top-travel-pro' ),
    'section'           => 'top_travel_pro_popular_posts_section',
    'on_off_label'      => top_travel_pro_switch_options(),
) ) );

// content type control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[popular_posts_count]', array(
    'default'           => $options['popular_posts_count'],
    'sanitize_callback' => 'top_travel_pro_sanitize_number_range',
    'validate_callback' => 'top_travel_pro_validate_popular_posts_count',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[popular_posts_count]', array(
    'label'             => esc_html__( 'Number of Slides', 'top-travel-pro' ),
    'description'       => esc_html__( 'Note: Min 5 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'top-travel-pro' ),
    'section'           => 'top_travel_pro_popular_posts_section',
    'active_callback'   => 'top_travel_pro_is_popular_posts_section_enable',
    'type'              => 'number',
    'input_attrs'       => array(
        'min'   => 5,
        'max'   => 10,
        'style' => 'width: 100px;'
        ),
) );

// Popular Posts content type control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[popular_posts_content_type]', array(
    'default'           => $options['popular_posts_content_type'],
    'sanitize_callback' => 'top_travel_pro_sanitize_select',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[popular_posts_content_type]', array(
    'label'             => esc_html__( 'Content Type', 'top-travel-pro' ),
    'section'           => 'top_travel_pro_popular_posts_section',
    'type'              => 'select',
    'active_callback'   => 'top_travel_pro_is_popular_posts_section_enable',
    'choices'           => array( 
        'page'      => esc_html__( 'Page', 'top-travel-pro' ),
        'post'      => esc_html__( 'Post', 'top-travel-pro' ),
        'category'  => esc_html__( 'Category', 'top-travel-pro' ),
    ),
) );

for ( $i = 1; $i <= $options['popular_posts_count']; $i++ ) :
    // popular_posts pages drop down chooser control and setting
    $wp_customize->add_setting( 'top_travel_pro_theme_options[popular_posts_content_page_' . $i . ']', array(
        'sanitize_callback' => 'top_travel_pro_sanitize_page',
    ) );

    $wp_customize->add_control( new Top_Travel_Pro_Dropdown_Chooser( $wp_customize, 'top_travel_pro_theme_options[popular_posts_content_page_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Page %d', 'top-travel-pro' ), $i ),
        'section'           => 'top_travel_pro_popular_posts_section',
        'choices'           => top_travel_pro_page_choices(),
        'active_callback'   => 'top_travel_pro_is_popular_posts_section_content_page_enable',
    ) ) );

    // popular_posts posts drop down chooser control and setting
    $wp_customize->add_setting( 'top_travel_pro_theme_options[popular_posts_content_post_' . $i . ']', array(
        'sanitize_callback' => 'top_travel_pro_sanitize_page',
    ) );

    $wp_customize->add_control( new Top_Travel_Pro_Dropdown_Chooser( $wp_customize, 'top_travel_pro_theme_options[popular_posts_content_post_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Post %d', 'top-travel-pro' ), $i ),
        'section'           => 'top_travel_pro_popular_posts_section',
        'choices'           => top_travel_pro_post_choices(),
        'active_callback'   => 'top_travel_pro_is_popular_posts_section_content_post_enable',
    ) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'top_travel_pro_theme_options[popular_posts_content_category]', array(
    'sanitize_callback' => 'top_travel_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'top_travel_pro_theme_options[popular_posts_content_category]', array(
    'label'             => esc_html__( 'Select Category', 'top-travel-pro' ),
    'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'top-travel-pro' ),
    'section'           => 'top_travel_pro_popular_posts_section',
    'type'              => 'dropdown-taxonomies',
    'active_callback'   => 'top_travel_pro_is_popular_posts_section_content_category_enable'
) ) );