<?php
/**
 * Service Section options
 *
 * @package Theme Palace
 * @subpackage Top Travel Pro
 * @since Top Travel Pro 1.0.0
 */

// Add Service section
$wp_customize->add_section( 'top_travel_pro_service_section', array(
	'title'             => esc_html__( 'Services','top-travel-pro' ),
	'description'       => esc_html__( 'Services Section options.', 'top-travel-pro' ),
	'panel'             => 'top_travel_pro_front_page_panel',	
	'active_callback' 	=> 'top_travel_pro_is_service_design_enable',
) );

// Service content enable control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[service_section_enable]', array(
	'default'			=> 	$options['service_section_enable'],
	'sanitize_callback' => 'top_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Top_Travel_Pro_Switch_Control( $wp_customize, 'top_travel_pro_theme_options[service_section_enable]', array(
	'label'             => esc_html__( 'Service Section Enable', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_service_section',
	'on_off_label' 		=> top_travel_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[service_section_enable]', array(
		'selector'            => '#our-services .wrapper',
		'settings'            => 'top_travel_pro_theme_options[service_section_enable]',
    ) );
}

// service title setting and control
$wp_customize->add_setting( 'top_travel_pro_theme_options[service_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['service_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[service_title]', array(
	'label'           	=> esc_html__( 'Title', 'top-travel-pro' ),
	'section'        	=> 'top_travel_pro_service_section',
	'active_callback' 	=> 'top_travel_pro_is_service_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[service_title]', array(
		'selector'            => '#our-services .section-header h2.section-title',
		'settings'            => 'top_travel_pro_theme_options[service_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'top_travel_pro_service_title_partial',
    ) );
}

// service title setting and control
$wp_customize->add_setting( 'top_travel_pro_theme_options[service_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['service_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[service_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'top-travel-pro' ),
	'section'        	=> 'top_travel_pro_service_section',
	'active_callback' 	=> 'top_travel_pro_is_service_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[service_sub_title]', array(
		'selector'            => '#our-services .section-header p.section-subtitle',
		'settings'            => 'top_travel_pro_theme_options[service_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'top_travel_pro_service_sub_title_partial',
    ) );
}

// service title setting and control
$wp_customize->add_setting( 'top_travel_pro_theme_options[service_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['service_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[service_btn_title]', array(
	'label'           	=> esc_html__( 'Btn Title', 'top-travel-pro' ),
	'section'        	=> 'top_travel_pro_service_section',
	'active_callback' 	=> 'top_travel_pro_is_service_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[service_btn_title]', array(
		'selector'            => '#our-services .read-more a',
		'settings'            => 'top_travel_pro_theme_options[service_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'top_travel_pro_service_btn_title_partial',
    ) );
}

$wp_customize->add_setting( 'top_travel_pro_theme_options[service_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[service_btn_url]', array(
	'label'           	=> esc_html__( 'Btn Url', 'top-travel-pro' ),
	'section'        	=> 'top_travel_pro_service_section',
	'active_callback' 	=> 'top_travel_pro_is_service_section_enable',
	'type'				=> 'url',
) );

$wp_customize->add_setting( 'top_travel_pro_theme_options[service_section_icon_enable]', array(
	'default'			=> 	$options['service_section_icon_enable'],
	'sanitize_callback' => 'top_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Top_Travel_Pro_Switch_Control( $wp_customize, 'top_travel_pro_theme_options[service_section_icon_enable]', array(
	'label'             => esc_html__( 'Service Section Icon Enable', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_service_section',
	'active_callback'   => 'top_travel_pro_is_service_section_enable',
	'on_off_label' 		=> top_travel_pro_switch_options(),
) ) );

// Servuce count number control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[service_count]', array(
	'default'          	=> $options['service_count'],
	'sanitize_callback' => 'top_travel_pro_sanitize_number_range',
	'validate_callback' => 'top_travel_pro_validate_service_count',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[service_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'top-travel-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_service_section',
	'active_callback'   => 'top_travel_pro_is_service_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Service content type control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[service_content_type]', array(
	'default'          	=> $options['service_content_type'],
	'sanitize_callback' => 'top_travel_pro_sanitize_select',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[service_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_service_section',
	'type'				=> 'select',
	'active_callback' 	=> 'top_travel_pro_is_service_section_enable',
	'choices'			=> top_travel_pro_service_content_type(),
) );

for ( $i = 1; $i <= $options['service_count']; $i++ ) :

	// service note control and setting
	$wp_customize->add_setting( 'top_travel_pro_theme_options[service_content_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Top_Travel_Pro_Icon_Picker( $wp_customize, 'top_travel_pro_theme_options[service_content_icon_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Icon %d', 'top-travel-pro' ), $i ),
		'section'           => 'top_travel_pro_service_section',
		'active_callback'	=> 'top_travel_pro_is_service_section_icon_enable',
	) ) );

	// service pages drop down chooser control and setting
	$wp_customize->add_setting( 'top_travel_pro_theme_options[service_content_page_' . $i . ']', array(
		'sanitize_callback' => 'top_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Chooser( $wp_customize, 'top_travel_pro_theme_options[service_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'top-travel-pro' ), $i ),
		'section'           => 'top_travel_pro_service_section',
		'choices'			=> top_travel_pro_page_choices(),
		'active_callback'	=> 'top_travel_pro_is_service_section_content_page_enable',
	) ) );

	// service posts drop down chooser control and setting
	$wp_customize->add_setting( 'top_travel_pro_theme_options[service_content_post_' . $i . ']', array(
		'sanitize_callback' => 'top_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Chooser( $wp_customize, 'top_travel_pro_theme_options[service_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'top-travel-pro' ), $i ),
		'section'           => 'top_travel_pro_service_section',
		'choices'			=> top_travel_pro_post_choices(),
		'active_callback'	=> 'top_travel_pro_is_service_section_content_post_enable',
	) ) );

	$wp_customize->add_setting( 'top_travel_pro_theme_options[service_content_trip_' . $i . ']', array(
		'sanitize_callback' => 'top_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Chooser( $wp_customize, 'top_travel_pro_theme_options[service_content_trip_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Trip %d', 'top-travel-pro' ), $i ),
		'section'           => 'top_travel_pro_service_section',
		'choices'			=> top_travel_pro_trip_choices(),
		'active_callback'	=> 'top_travel_pro_is_service_section_content_trip_enable',
	) ) );

	// service hr setting and control
	$wp_customize->add_setting( 'top_travel_pro_theme_options[service_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Top_Travel_Pro_Customize_Horizontal_Line( $wp_customize, 'top_travel_pro_theme_options[service_hr_'. $i .']',
		array(
			'section'         => 'top_travel_pro_service_section',
			'active_callback' => 'top_travel_pro_is_service_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'top_travel_pro_theme_options[service_content_category]', array(
	'sanitize_callback' => 'top_travel_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'top_travel_pro_theme_options[service_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'top-travel-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_service_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'top_travel_pro_is_service_section_content_category_enable'
) ) );

$wp_customize->add_setting(  'top_travel_pro_theme_options[service_content_trip_types]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'top_travel_pro_theme_options[service_content_trip_types]', array(
	'label'             => esc_html__( 'Select Trip Types', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_service_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'top_travel_pro_is_service_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'top_travel_pro_theme_options[service_content_activity]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'top_travel_pro_theme_options[service_content_activity]', array(
	'label'             => esc_html__( 'Select Activities', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_service_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'top_travel_pro_is_service_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'top_travel_pro_theme_options[service_content_destination]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'top_travel_pro_theme_options[service_content_destination]', array(
	'label'             => esc_html__( 'Select Destinations', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_service_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'top_travel_pro_is_service_section_content_destination_enable'
) ) );

/*color options*/

// Section sub title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[section_subtitle_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[section_subtitle_color]', array(
	'label'             => esc_html__( 'Section Sub Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_service_section',
	'active_callback' 	=> 'top_travel_pro_is_service_section_enable',
	) ) );

// Section title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[section_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[section_title_color]', array(
	'label'             => esc_html__( 'Section Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_service_section',
	'active_callback' 	=> 'top_travel_pro_is_service_section_enable',
	) ) );

// Service title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[service_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[service_title_color]', array(
	'label'             => esc_html__( 'Service Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_service_section',
	'active_callback' 	=> 'top_travel_pro_is_service_section_enable',
	) ) );

// Service title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[service_hover_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[service_hover_title_color]', array(
	'label'             => esc_html__( 'Service Hover Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_service_section',
	'active_callback' 	=> 'top_travel_pro_is_service_section_enable',
	) ) );

// Service description color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[service_description_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[service_description_color]', array(
	'label'             => esc_html__( 'Service Description Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_service_section',
	'active_callback' 	=> 'top_travel_pro_is_service_section_enable',
	) ) );

// Service icon color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[service_icon_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[service_icon_color]', array(
	'label'             => esc_html__( 'Service Icon Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_service_section',
	'active_callback' 	=> 'top_travel_pro_is_service_section_enable',
	) ) );

// Service icon hover color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[service_icon_hover_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[service_icon_hover_color]', array(
	'label'             => esc_html__( 'Service Icon Hover Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_service_section',
	'active_callback' 	=> 'top_travel_pro_is_service_section_enable',
	) ) );

// Header title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[service_button_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[service_button_color]', array(
	'label'             => esc_html__( 'Button Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_service_section',
	'active_callback' 	=> 'top_travel_pro_is_service_section_enable',
	) ) );

// Header title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[service_button_hover_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[service_button_hover_color]', array(
	'label'             => esc_html__( 'Button Hover Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_service_section',
	'active_callback' 	=> 'top_travel_pro_is_service_section_enable',
	) ) );

// Button title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[service_btn_text_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[service_btn_text_color]', array(
	'label'             => esc_html__( 'Button Text Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_service_section',
	'active_callback' 	=> 'top_travel_pro_is_service_section_enable',
	) ) );