<?php
/**
 * Team Section options
 *
 * @package Theme Palace
 * @subpackage Top Travel Pro
 * @since Top Travel Pro 1.0.0
 */

// Add Team section
$wp_customize->add_section( 'top_travel_pro_team_section', array(
	'title'             => esc_html__( 'Teams','top-travel-pro' ),
	'description'       => esc_html__( 'Teams Section options.', 'top-travel-pro' ),
	'panel'             => 'top_travel_pro_front_page_panel',
	'active_callback' 	=> 'top_travel_pro_is_team_design_enable',
) );

// Team content enable control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[team_section_enable]', array(
	'default'			=> 	$options['team_section_enable'],
	'sanitize_callback' => 'top_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Top_Travel_Pro_Switch_Control( $wp_customize, 'top_travel_pro_theme_options[team_section_enable]', array(
	'label'             => esc_html__( 'Team Section Enable', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_team_section',
	'on_off_label' 		=> top_travel_pro_switch_options(),
) ) );


if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[team_section_enable]', array(
		'selector'            => '.team-section .team-wrapper',
		'settings'            => 'top_travel_pro_theme_options[team_section_enable]',
    ) );
}

// team title setting and control
$wp_customize->add_setting( 'top_travel_pro_theme_options[team_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['team_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[team_title]', array(
	'label'           	=> esc_html__( 'Title', 'top-travel-pro' ),
	'section'        	=> 'top_travel_pro_team_section',
	'active_callback' 	=> 'top_travel_pro_is_team_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[team_title]', array(
		'selector'            => '.team-section h2.team-title',
		'settings'            => 'top_travel_pro_theme_options[team_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'top_travel_pro_team_title_partial',
    ) );
}

// team sub title
$wp_customize->add_setting( 'top_travel_pro_theme_options[team_sub_title]', array(
	'default'          	=> $options['team_sub_title'],
	'sanitize_callback' => 'sanitize_textarea_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[team_sub_title]', array(
	'label'             => esc_html__( 'Sub Title', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_team_section',
	'active_callback'	=> 'top_travel_pro_is_team_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'top_travel_pro_theme_options[team_sub_title]', array(
		'selector'            => '.team-section p.team-subtitle',
		'settings'            => 'top_travel_pro_theme_options[team_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'top_travel_pro_team_sub_title_partial',
    ) );
}

// team content type control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[team_column]', array(
	'default'          	=> $options['team_column'],
	'sanitize_callback' => 'top_travel_pro_sanitize_select',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[team_column]', array(
	'label'             => esc_html__( 'Column Layout', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_team_section',
	'type'				=> 'select',
	'active_callback' 	=> 'top_travel_pro_is_team_section_enable',
	'choices'			=> array(
		'3'		=> esc_html__( 'Three Column', 'top-travel-pro' ),
		'4'		=> esc_html__( 'Four Column', 'top-travel-pro' ),
	),
) );

// Team content type control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[team_content_type]', array(
	'default'          	=> $options['team_content_type'],
	'sanitize_callback' => 'top_travel_pro_sanitize_select',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[team_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_team_section',
	'type'				=> 'select',
	'active_callback' 	=> 'top_travel_pro_is_team_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'top-travel-pro' ),
		'post' 		=> esc_html__( 'Post', 'top-travel-pro' ),
		'category' 	=> esc_html__( 'Category', 'top-travel-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'top_travel_pro_theme_options[team_count]', array(
	'default'          	=> $options['team_count'],
	'sanitize_callback' => 'top_travel_pro_sanitize_number_range',
) );

$wp_customize->add_control( 'top_travel_pro_theme_options[team_count]', array(
	'label'             => esc_html__( 'Number of Teams', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_team_section',
	'active_callback'   => 'top_travel_pro_is_team_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'style' => 'width: 100px;'
		),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'top_travel_pro_theme_options[team_content_category]', array(
	'sanitize_callback' => 'top_travel_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'top_travel_pro_theme_options[team_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'top-travel-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_team_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'top_travel_pro_is_team_section_content_category_enable'
) ) );


for ( $i = 1; $i <= $options['team_count']; $i++ ) :

	// team pages drop down chooser control and setting
	$wp_customize->add_setting( 'top_travel_pro_theme_options[team_content_page_' . $i . ']', array(
		'sanitize_callback' => 'top_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Chooser( $wp_customize, 'top_travel_pro_theme_options[team_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'top-travel-pro' ), $i ),
		'section'           => 'top_travel_pro_team_section',
		'choices'			=> top_travel_pro_page_choices(),
		'active_callback'	=> 'top_travel_pro_is_team_section_content_page_enable',
	) ) );

	// team posts drop down chooser control and setting
	$wp_customize->add_setting( 'top_travel_pro_theme_options[team_content_post_' . $i . ']', array(
		'sanitize_callback' => 'top_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Top_Travel_Pro_Dropdown_Chooser( $wp_customize, 'top_travel_pro_theme_options[team_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'top-travel-pro' ), $i ),
		'section'           => 'top_travel_pro_team_section',
		'choices'			=> top_travel_pro_post_choices(),
		'active_callback'	=> 'top_travel_pro_is_team_section_content_post_enable',
	) ) );

	// team custom content
	$wp_customize->add_setting( 'top_travel_pro_theme_options[team_position_' . $i . ']', array(
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( 'top_travel_pro_theme_options[team_position_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Position %d', 'top-travel-pro' ), $i ),
		'section'           => 'top_travel_pro_team_section',
		'active_callback'	=> 'top_travel_pro_is_team_section_enable',
	) );

	// team social
	$wp_customize->add_setting( 'top_travel_pro_theme_options[team_social_' . $i. ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new Top_Travel_Pro_Multi_Input_Custom_Control( $wp_customize, 'top_travel_pro_theme_options[team_social_' . $i. ']', array(
		'label'             => esc_html__( 'Social ', 'top-travel-pro' ),
		'button_text'       => esc_html__( 'Add social.', 'top-travel-pro' ),
		'section'           => 'top_travel_pro_team_section',
		'active_callback' 	=> 'top_travel_pro_is_team_section_enable',
	) ) );

	// team hr setting and control
	$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[team_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Top_Travel_Pro_Customize_Horizontal_Line( $wp_customize, 'travel_ultimate_pro_theme_options[team_hr_'. $i .']',
		array(
			'section'         => 'top_travel_pro_team_section',
			'active_callback' => 'top_travel_pro_is_team_section_enable',
			'type'			  => 'hr'
	) ) );
endfor;

/*color options*/

// Section sub title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[package_section_subtitle_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[package_section_subtitle_color]', array(
	'label'             => esc_html__( 'Section Sub Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_team_section',
	'active_callback' 	=> 'top_travel_pro_is_team_section_enable',
	) ) );

// Section title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[package_section_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[package_section_title_color]', array(
	'label'             => esc_html__( 'Section Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_team_section',
	'active_callback' 	=> 'top_travel_pro_is_team_section_enable',
	) ) );

// Team title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[package_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[package_title_color]', array(
	'label'             => esc_html__( 'Team Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_team_section',
	'active_callback' 	=> 'top_travel_pro_is_team_section_enable',
	) ) );

// Team title color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[package_hover_title_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[package_hover_title_color]', array(
	'label'             => esc_html__( 'Team Hover Title Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_team_section',
	'active_callback' 	=> 'top_travel_pro_is_team_section_enable',
	) ) );

// Team description color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[package_description_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[package_description_color]', array(
	'label'             => esc_html__( 'Team Position Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_team_section',
	'active_callback' 	=> 'top_travel_pro_is_team_section_enable',
	) ) );

// Team description color setting and control.
$wp_customize->add_setting( 'top_travel_pro_theme_options[package_social_icon_color]', array(
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
	) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'top_travel_pro_theme_options[package_social_icon_color]', array(
	'label'             => esc_html__( 'Social Icon Color', 'top-travel-pro' ),
	'section'           => 'top_travel_pro_team_section',
	'active_callback' 	=> 'top_travel_pro_is_team_section_enable',
	) ) );