<?php
/**
 * Popular Posts section
 *
 * This is the template for the content of popular_posts section
 *
 * @package Theme Palace
 * @subpackage Top Travel Pro
 * @since Top Travel Pro 1.0.0
 */
if ( ! function_exists( 'top_travel_pro_add_popular_posts_section' ) ) :
    /**
    * Add popular_posts section
    *
    *@since Top Travel Pro 1.0.0
    */
    function top_travel_pro_add_popular_posts_section() {
        $options = top_travel_pro_get_theme_options();
        // Check if popular_posts is enabled on frontpage
        $popular_posts_enable = apply_filters( 'top_travel_pro_section_status', true, 'popular_posts_section_enable' );

         if ( !in_array( $options['home_layout'], array( 'fifth-design' ) ) ) {
             $popular_posts_enable = false;
        }

        if ( true !== $popular_posts_enable ) {
            return false;
        }
        // Get popular_posts section details
        $section_details = array();
        $section_details = apply_filters( 'top_travel_pro_filter_popular_posts_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render popular_posts section now.
        top_travel_pro_render_popular_posts_section( $section_details );
    }
endif;

if ( ! function_exists( 'top_travel_pro_get_popular_posts_section_details' ) ) :
    /**
    * popular_posts section details.
    *
    * @since Top Travel Pro 1.0.0
    * @param array $input popular_posts section details.
    */
    function top_travel_pro_get_popular_posts_section_details( $input ) {
        $options = top_travel_pro_get_theme_options();

        // Content type.
        $popular_posts_content_type  = $options['popular_posts_content_type'];
        $popular_posts_count = ! empty( $options['popular_posts_count'] ) ? $options['popular_posts_count'] : 5;
        $content = array();
        switch ( $popular_posts_content_type ) {
            
            case 'page':
                $page_ids = array();
                $author = array();

                for ( $i = 1; $i <= $popular_posts_count; $i++ ) {
                    if ( ! empty( $options['popular_posts_content_page_' . $i] ) ) :
                        $page_ids[] = $options['popular_posts_content_page_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $popular_posts_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();
                $author = array();

                for ( $i = 1; $i <= $popular_posts_count; $i++ ) {
                    if ( ! empty( $options['popular_posts_content_post_' . $i] ) ) :
                        $post_ids[] = $options['popular_posts_content_post_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $popular_posts_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['popular_posts_content_category'] ) ? $options['popular_posts_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $popular_posts_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;
            
            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        $i = 0;
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
                $i++;
            endwhile;
        endif;
        wp_reset_postdata();
   
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// popular_posts section content details.
add_filter( 'top_travel_pro_filter_popular_posts_section_details', 'top_travel_pro_get_popular_posts_section_details' );


if ( ! function_exists( 'top_travel_pro_render_popular_posts_section' ) ) :
  /**
   * Start popular_posts section
   *
   * @return string popular_posts content
   * @since Top Travel Pro 1.0.0
   *
   */
   function top_travel_pro_render_popular_posts_section( $content_details = array() ) {
        $options = top_travel_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="top_travel_pro_popular_posts_section">
            <div id="magazine-popular-posts">
                <div class="wrapper">
                    <div class="col-3 grid clear">

                    <?php foreach ( $content_details as $content ): ?>

                        <article class="grid-item">
                            <div class="popular-post-item">
                                <div class="featured-image">
                                    <img src="<?php echo esc_url( $content['image'] ); ?>">
                                </div><!-- .featured-image -->

                                <div class="entry-container">
                                    <ul class="post-categories">
                                         <?php the_category( '', '', $content['id'] ) ?>
                                    </ul>

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>   

                                    <?php top_travel_pro_posted_on( $content['id'] ); ?>
                                </div><!-- .entry-container -->
                            </div><!-- .popular-post-item -->
                        </article>

                    <?php endforeach; ?>

                    </div><!-- .col-3 -->
                </div><!-- .wrapper -->
            </div><!-- #magazine-popular-posts -->

        </div>
      
    <?php }
endif;