<?php
/**
 * Slider section
 *
 * This is the template for the content of slider section
 *
 * @package Theme Palace
 * @subpackage Top Travel Pro
 * @since Top Travel Pro 1.0.0
 */
if ( ! function_exists( 'top_travel_pro_add_slider_section' ) ) :
    /**
    * Add slider section
    *
    *@since Top Travel Pro 1.0.0
    */
    function top_travel_pro_add_slider_section() {
    	$options = top_travel_pro_get_theme_options();
        // Check if slider is enabled on frontpage
        $slider_enable = apply_filters( 'top_travel_pro_section_status', true, 'slider_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'default-design', 'second-design', 'third-design', 'fourth-design', 'sixth-design', 'seventh-design', 'eighth-design', 'ninth-design', 'tenth-design' ) ) ) {
             $slider_enable = false;
        }

        if ( true !== $slider_enable ) {
            return false;
        }
        // Get slider section details
        $section_details = array();
        $section_details = apply_filters( 'top_travel_pro_filter_slider_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render slider section now.
        top_travel_pro_render_slider_section( $section_details );
    }
endif;

if ( ! function_exists( 'top_travel_pro_get_slider_section_details' ) ) :
    /**
    * slider section details.
    *
    * @since Top Travel Pro 1.0.0
    * @param array $input slider section details.
    */
    function top_travel_pro_get_slider_section_details( $input ) {
        $options = top_travel_pro_get_theme_options();

        // Content type.
        $slider_content_type  = $options['slider_content_type'];
        $slider_count = ! empty( $options['slider_count'] ) ? $options['slider_count'] : 3;
        
        $content = array();
        switch ( $slider_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $slider_count; $i++ ) {
                    if ( ! empty( $options['slider_content_page_' . $i] ) )
                        $page_ids[] = $options['slider_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $slider_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $slider_count; $i++ ) {
                    if ( ! empty( $options['slider_content_post_' . $i] ) )
                        $post_ids[] = $options['slider_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $slider_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['slider_content_category'] ) ? $options['slider_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $slider_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'trip':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                $page_ids = array();

                for ( $i = 1; $i <= $slider_count; $i++ ) {
                    if ( ! empty( $options['slider_content_trip_' . $i] ) )
                        $page_ids[] = $options['slider_content_trip_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'itineraries',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $slider_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'trip-types':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                $cat_id = ! empty( $options['slider_content_trip_types'] ) ? $options['slider_content_trip_types'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'itinerary_types',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $slider_count ),
                    );                    
            break;

            case 'destination':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                $cat_id = ! empty( $options['slider_content_destination'] ) ? $options['slider_content_destination'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'travel_locations',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $slider_count ),
                    );                    
            break;

            case 'activity':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                
                $cat_id = ! empty( $options['slider_content_activity'] ) ? $options['slider_content_activity'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'activity',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $slider_count ),
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = top_travel_pro_trim_content( 30 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// slider section content details.
add_filter( 'top_travel_pro_filter_slider_section_details', 'top_travel_pro_get_slider_section_details' );


if ( ! function_exists( 'top_travel_pro_render_slider_section' ) ) :
  /**
   * Start slider section
   *
   * @return string slider content
   * @since Top Travel Pro 1.0.0
   *
   */
   function top_travel_pro_render_slider_section( $content_details = array() ) {
        $options = top_travel_pro_get_theme_options();
        $btn_label = ! empty( $options['slider_btn_label'] ) ? $options['slider_btn_label'] : '';
        $dots = $options['home_layout'] == 'default-design' ? 'false' : 'true';
        $arrows = $options['slider_arrow'] ? 'true' : 'false';
        $autoplay = $options['slider_autoplay'] ? 'true' : 'false';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="top_travel_slider_section">
            <div id="featured-slider-section" class="slider-section">
                <div class="featured-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": <?php echo esc_attr($dots); ?>, "arrows":<?php echo esc_attr($arrows); ?>, "autoplay": <?php echo esc_attr( $autoplay ); ?>, "draggable": true, "fade": true, "adaptiveHeight": true }'>
                    <?php $i = 1; foreach ( $content_details as $content ) : ?>
                        <article style="background-image:url('<?php echo esc_url( $content['image'] ); ?>');">
                            <div class="wrapper">
                                <div class="featured-content-wrapper">

                                <?php if ( $options['home_layout'] == 'third-design' ): ?>
                                    <span class="cat-links">
                                        <ul class="post-categories">
                                            <?php the_category( '', '', $content['id'] ) ?>
                                        </ul><!-- .post-categories -->
                                    </span><!-- .cat-links -->
                                <?php endif; ?>

                                    <?php if ( $options['home_layout'] == 'fourth-design' ){ 
                                        if( !empty( $options['slider_subtitle_'.$i] ) ):
                                            ?>
                                        <h3 class="slider-subtitle"><?php echo esc_html( $options['slider_subtitle_'.$i] ); ?></h3>
                                        <?php 
                                        endif;
                                    } ?>

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <?php if( in_array( $options['home_layout'], array( 'second-design', 'third-design', 'sixth-design', 'seventh-design', 'eighth-design', 'ninth-design', 'tenth-design' ) ) ): ?>

                                    <div class="entry-content">
                                        <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                    </div>

                                <?php endif; ?>

                                    <div class="read-more">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn btn-fill">
                                            <?php echo esc_html( $btn_label ); ?>
                                        </a>
                                    </div><!-- .read-more -->
                                </div><!-- .featured-content-wrapper -->
                            </div><!-- .wrapper -->
                        </article>
                    <?php $i++; endforeach; ?>
                </div><!-- .featured-slider -->  
            </div><!-- #featured-slider-section -->     
        </div>
       
    <?php }
endif;