<?php
/**
 * Trending section
 *
 * This is the template for the content of trending section
 *
 * @package Theme Palace
 * @subpackage Top Travel Pro
 * @since Top Travel Pro 1.0.0
 */
if ( ! function_exists( 'top_travel_pro_add_trending_section' ) ) :
    /**
    * Add trending section
    *
    *@since Top Travel Pro 1.0.0
    */
    function top_travel_pro_add_trending_section() {
        $options = top_travel_pro_get_theme_options();
        // Check if trending is enabled on frontpage
        $trending_enable = apply_filters( 'top_travel_pro_section_status', true, 'trending_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'default-design', 'third-design', 'eighth-design', 'ninth-design', 'tenth-design' ) ) ) {
             $trending_enable = false;
        }

        if ( true !== $trending_enable ) {
            return false;
        }
        // Get trending section details
        $section_details = array();
        $section_details = apply_filters( 'top_travel_pro_filter_trending_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render trending section now.
        top_travel_pro_render_trending_section( $section_details );
    }
endif;

if ( ! function_exists( 'top_travel_pro_get_trending_section_details' ) ) :
    /**
    * trending section details.
    *
    * @since Top Travel Pro 1.0.0
    * @param array $input trending section details.
    */
    function top_travel_pro_get_trending_section_details( $input ) {
        $options = top_travel_pro_get_theme_options();

        // Content type.
        $trending_content_type  = $options['trending_content_type'];
        $trending_count = ! empty( $options['trending_count'] ) ? $options['trending_count'] : 3;
        $content = array();
        switch ( $trending_content_type ) {
            
            case 'page':
                $page_ids = array();
                $author = array();

                for ( $i = 1; $i <= $trending_count; $i++ ) {
                    if ( ! empty( $options['trending_content_page_' . $i] ) ) :
                        $page_ids[] = $options['trending_content_page_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $trending_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();
                $author = array();

                for ( $i = 1; $i <= $trending_count; $i++ ) {
                    if ( ! empty( $options['trending_content_post_' . $i] ) ) :
                        $post_ids[] = $options['trending_content_post_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $trending_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['trending_content_category'] ) ? $options['trending_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $trending_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;
            
            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        $i = 0;
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = top_travel_pro_trim_content( 35 );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
                $i++;
            endwhile;
        endif;
        wp_reset_postdata();
   
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// trending section content details.
add_filter( 'top_travel_pro_filter_trending_section_details', 'top_travel_pro_get_trending_section_details' );


if ( ! function_exists( 'top_travel_pro_render_trending_section' ) ) :
  /**
   * Start trending section
   *
   * @return string trending content
   * @since Top Travel Pro 1.0.0
   *
   */
   function top_travel_pro_render_trending_section( $content_details = array() ) {
        $options = top_travel_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="top_travel_pro_trending_section">
             <div id="testimonial-section" class="relative page-section">
                <div class="wrapper">
                    <div class="section-header">
                    <?php if( !empty( $options['trending_subtitle'] ) ): ?>
                        <p class="section-subtitle"><?php echo esc_html( $options['trending_subtitle'] ); ?></p>
                    <?php endif; 
                    if( !empty( $options['trending_title'] ) ):
                    ?>
                        <h2 class="section-title"><?php echo esc_html( $options['trending_title'] ); ?></h2>
                    <?php endif; ?>
                    </div><!-- .section-header -->

                    <div class="testimonial-slider" data-slick='{"slidesToShow": 3, "slidesToScroll": 1, "infinite": false, "speed": 1000, "dots": false, "arrows":false, "autoplay": false, "draggable": true, "fade": false }'>

                    <?php foreach ( $content_details as $content ) : ?>
                        
                        <article>
                            <div class="featured-image">
                                <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>"></a>
                            </div><!-- .featured-image -->

                            <div class="entry-container">
                            <?php if( $options['home_layout'] == 'third-design' ): ?>
                                <span class="cat-links">
                                    <ul class="post-categories">
                                        <?php the_category( '', '', $content['id'] ) ?>
                                    </ul><!-- .post-categories -->                                                    
                                </span><!-- .cat-links -->
                            <?php endif; ?>

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>

                                <div class="entry-content">
                                    <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                </div><!-- .entry-content -->
                            </div><!-- .entry-container -->
                        </article>

                        <?php endforeach ; ?>

                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div>
        </div>
       

    <?php }
endif;
